@@ -109,10 +109,13 @@ def launch(
                 "Groups": security_group if isinstance(security_group, list) else [security_group],
             }
         ]
+        associate_public_ip_address = config["vpc"].get("associate_public_ip_address", None)
+        if associate_public_ip_address is not None:
+            runargs["NetworkInterfaces"][0]["AssociatePublicIpAddress"] = associate_public_ip_address
 
-    associate_public_ip_address = config["vpc"].get("associate_public_ip_address", None)
-    if associate_public_ip_address is not None:
-        runargs["NetworkInterfaces"][0]["AssociatePublicIpAddress"] = associate_public_ip_address
+        vpc_name = f" vpc {config['vpc']['name']}"
+    else:
+        vpc_name = ""
 
     iam_instance_profile_arn = config.get("iam_instance_profile_arn", None)
     if iam_instance_profile_arn:
@@ -121,9 +124,12 @@ def launch(
     if userdata:
         runargs["UserData"] = read_file(userdata)
 
+    # use IMDSv2 to prevent SSRF
+    runargs["MetadataOptions"] = {"HttpTokens": "required"}
+
     region_name = ec2_client.meta.region_name
 
-    print(f"Launching a {instance_type} in {region_name} vpc {config['vpc']['name']} named {name} using {desc} ... ")
+    print(f"Launching a {instance_type} in {region_name}{vpc_name} named {name} using {desc} ... ")
     response = ec2_client.run_instances(**runargs)
 
     instance = response["Instances"][0]
@@ -144,6 +150,7 @@ def describe(
     name_match: Optional[str] = None,
     include_terminated: bool = False,
     show_running_only: bool = False,
+    sort_by: str = "State,Name",
 ) -> List[Dict[str, Any]]:
     """List EC2 instances in the region."""
 
@@ -169,7 +176,10 @@ def describe(
         and (not show_running_only or i["State"]["Name"] in ["pending", "running"])
     ]
 
-    return sorted(instances, key=lambda i: i["State"] + str(i["Name"]))
+    return sorted(
+        instances,
+        key=lambda i: "".join(str(i[field]) for field in sort_by.split(",")),
+    )
 
 
 def tags(
