@@ -2,38 +2,52 @@ import codecs
 import json
 import sys
 import uuid
-from typing import IO, Any, Dict, List, Optional, Sequence, TypeVar, cast
+from typing import IO, Any, Dict, Iterator, List, Optional, Sequence, TypeVar, cast
 
 import boto3
 from botocore.exceptions import ClientError
-from typing_extensions import Literal
+from typing_extensions import Literal, TypedDict
 
 import aec.util.tags as util_tags
 from aec.util.config import Config
 
 
-def describe(config: Config) -> List[Dict[str, Any]]:
+class Agent(TypedDict):
+    ID: str
+    Name: Optional[str]
+    PingStatus: str
+    Platform: str
+    AgentVersion: Optional[str]
+
+
+def describe(config: Config) -> Iterator[Agent]:
     """List running instances with the SSM agent."""
 
     instances_names = describe_instances_names(config)
 
+    kwargs = {"MaxResults": 50}
     client = boto3.client("ssm", region_name=config.get("region", None))
+    while True:
+        response = client.describe_instance_information(**kwargs)
 
-    response = client.describe_instance_information()
+        for i in response["InstanceInformationList"]:
+            a: Agent = {
+                "ID": i["InstanceId"],
+                "Name": instances_names.get(i["InstanceId"], None),
+                "PingStatus": i["PingStatus"],
+                "Platform": f'{i["PlatformName"]} {i["PlatformVersion"]}',
+                "AgentVersion": i["AgentVersion"],
+            }
+            yield a
 
-    return [
-        {
-            "ID": i["InstanceId"],
-            "Name": instances_names.get(i["InstanceId"], None),
-            "PingStatus": i["PingStatus"],
-            "Platform": f'{i["PlatformName"]} {i["PlatformVersion"]}',
-            "AgentVersion": i["AgentVersion"],
-        }
-        for i in response["InstanceInformationList"]
-    ]
+        next_token = response.get("NextToken", None)
+        if next_token:
+            kwargs = {"NextToken": next_token}
+        else:
+            break
 
 
-def patch_summary(config: Config) -> List[Dict[str, Optional[str]]]:
+def patch_summary(config: Config) -> Iterator[Dict[str, Any]]:
     """Patch summary for all instances that have run the patch baseline."""
     instances_names = describe_instances_names(config)
     instance_ids = list(instances_names.keys())
@@ -41,27 +55,21 @@ def patch_summary(config: Config) -> List[Dict[str, Optional[str]]]:
     client = boto3.client("ssm", region_name=config.get("region", None))
 
     max_at_a_time = 50
-    result = []
+
     for i in range(0, len(instance_ids), max_at_a_time):
         chunk = instance_ids[i : i + max_at_a_time]
         response = client.describe_instance_patch_states(InstanceIds=chunk)
-        result.extend(
-            [
-                {
-                    "InstanceId": i["InstanceId"],
-                    "Name": instances_names.get(i["InstanceId"], None),
-                    "Needed": i["MissingCount"],
-                    "Pending Reboot": i["InstalledPendingRebootCount"],
-                    "Errored": i["FailedCount"],
-                    "Rejected": i["InstalledRejectedCount"],
-                    "Last operation time": i["OperationEndTime"],
-                    "Last operation": i["Operation"],
-                }
-                for i in response["InstancePatchStates"]
-            ]
-        )
-
-    return result
+        for i in response["InstancePatchStates"]:
+            yield {
+                "InstanceId": i["InstanceId"],
+                "Name": instances_names.get(i["InstanceId"], None),
+                "Needed": i["MissingCount"],
+                "Pending Reboot": i["InstalledPendingRebootCount"],
+                "Errored": i["FailedCount"],
+                "Rejected": i["InstalledRejectedCount"],
+                "Last operation time": i["OperationEndTime"],
+                "Last operation": i["Operation"],
+            }
 
 
 def compliance_summary(config: Config) -> List[Dict[str, Any]]:
